@@ -28,7 +28,6 @@
 #include <KCmdLineArgs>
 #include <KServiceTypeTrader>
 #include <KSharedConfig>
-#include <KConfigGroup>
 
 #include <Activities.h>
 #include <Resources.h>
@@ -39,15 +38,14 @@
 #include <stdlib.h>
 #include <memory>
 
-#include "jobs/encryption/Common.h"
-
 #include <utils/nullptr.h>
 #include <utils/override.h>
 #include <utils/d_ptr_implementation.h>
 #include <utils/val.h>
 
-static QList < QThread * > s_moduleThreads;
-
+namespace {
+    QList < QThread * > s_moduleThreads;
+}
 
 // Runs a QObject inside a QThread
 
@@ -134,7 +132,7 @@ void Application::loadPlugins()
             disabledPlugins << plugin;
     }
 
-    // Adding overriden plugins into the list of disabled ones
+    // Adding overridden plugins into the list of disabled ones
 
     foreach (val & service, offers) {
         if (!disabledPlugins.contains(service->library())) {
@@ -147,7 +145,6 @@ void Application::loadPlugins()
     qDebug() << "These are the disabled plugins:" << disabledPlugins;
 
     // Loading plugins and initializing them
-
     foreach (val & service, offers) {
         if (disabledPlugins.contains(service->library()) ||
                 disabledPlugins.contains(service->property("X-KDE-PluginInfo-Name").toString() + "Enabled")) {
@@ -163,11 +160,14 @@ void Application::loadPlugins()
         val plugin = factory->create < Plugin > (this);
 
         if (plugin) {
-            qDebug() << "Initializing plugin:" << service->library();
-            plugin->init(Module::get());
+            qDebug() << "Got the plugin: " << service->library();
             d->plugins << plugin;
         }
     }
+
+    foreach (Plugin * plugin, d->plugins) {
+        plugin->init(Module::get());
+    }
 }
 
 Application::~Application()
@@ -220,12 +220,8 @@ void Application::quit()
 }
 
 
-
 // Leaving object oriented world :)
 
-static void initSignalCatching();
-
-
 int main(int argc, char ** argv)
 {
     KAboutData about("kactivitymanagerd", nullptr, ki18n("KDE Activity Manager"), "3.0",
@@ -236,50 +232,6 @@ int main(int argc, char ** argv)
 
     KCmdLineArgs::init(argc, argv, &about);
 
-    if (!KCmdLineArgs::allArguments().contains("--nofork"))
-        initSignalCatching();
-
     return Application::self()->exec();
 }
 
-// Signal handling
-static void signalHandler(int sig)
-{
-    Jobs::Encryption::Common::unmountAll();
-
-    Application::quit();
-
-    // something (probably ksmserver) has asked us to terminate.
-    // If it is really ksmserver then the user is probably logging out, so we
-    // had better gently stop now than be killed.
-    if (sig == SIGTERM) {
-        //qDebug() << "signalHandler(SIGTERM): stopping ActivityManager\n";
-
-        // ActivityManager::self()->Stop();
-    }
-
-    // If we have crashed, then restart
-    if (sig == SIGSEGV) {
-        qDebug() << "Calling the crash handler...";
-        KCrash::defaultCrashHandler(SIGSEGV);
-    }
-
-    ::exit(EXIT_SUCCESS);
-}
-
-static void initSignalCatching() {
-#ifndef Q_OS_WIN32 // krazy:skip
-    struct sigaction action;
-
-    ::sigemptyset(&action.sa_mask);
-    action.sa_flags = 0;
-
-    /* Use the sa_sigaction field because the handles has two additional parameters */
-    action.sa_handler = signalHandler;
-
-    ::sigaction(SIGINT,  &action, nullptr);
-    ::sigaction(SIGHUP,  &action, nullptr);
-    ::sigaction(SIGTERM, &action, nullptr);
-    ::sigaction(SIGSEGV, &action, nullptr);
-#endif
-}
